var spider = require('../');
var should = require('should');
var path = require('path');
var gutil = require('gulp-util');
var fs = require('fs');

function createVinyl(spiderFileName, contents) {
  var base = path.join(__dirname, 'fixtures');
  var filePath = path.join(base, spiderFileName);

  return new gutil.File({
    cwd: __dirname,
    base: base,
    path: filePath,
    contents: contents || fs.readFileSync(filePath)
  });
}

describe('gulp-spider', function () {
  describe('spider()', function () {
    it('should pass file when it isNull()', function (done) {
      var stream = spider();
      var emptyFile = {
        isNull: function () { return true; }
      };
      stream.on('data', function (data) {
        data.should.equal(emptyFile);
        done();
      });
      stream.write(emptyFile);
    });

    it('should emit error when file isStream()', function (done) {
      var stream = spider();
      var streamFile = {
        isNull: function () { return false; },
        isStream: function () { return true; }
      };
      stream.on('error', function (err) {
        err.message.should.equal('Streaming not supported');
        done();
      });
      stream.write(streamFile);
    });

    it('should compile single spider file', function (done) {
      var spiderFile = createVinyl('code.spider');
      var stream = spider();

      stream.on('data', function (jsFile) {
        should.exist(jsFile);
        should.exist(jsFile.path);
        should.exist(jsFile.relative);
        should.exist(jsFile.contents);
        jsFile.path.should.equal(path.join(__dirname, 'fixtures', 'code.js'));
        String(jsFile.contents).should.equal(
          fs.readFileSync(path.join(__dirname, 'expect/code.js'), 'utf8'));
        done();
      });
      stream.write(spiderFile);
    });
  });
});
